@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2013 Almar Klein
 
-""" 
+"""
 Defines the tree widget to display the contents of a selected directory.
 """
 
 
 import os
 import sys
-import time
 import subprocess
 import fnmatch
 import os.path as op
@@ -50,11 +49,7 @@ def addIconOverlays(icon, *overlays, offset=(8,0), overlay_offset=(0,0)):
 
 
 
-def _filterFileByName(basename, filter):
-    
-    # Get the current filter spec and split it into separate filters
-    filters = filter.replace(',', ' ').split()
-    filters = [f for f in filters if f]
+def _filterFileByName(basename, filters):
     
     # Init default; return True if there are no filters
     default = True
@@ -84,7 +79,7 @@ def createMounts(browser, tree):
     mountPoints.sort(key=lambda x: x.lower())
     for entry in mountPoints:
         entry = cleanpath(entry)
-        item = DriveItem(tree, fsProxy.dir(entry))
+        DriveItem(tree, fsProxy.dir(entry))
 
 
 def createItemsFun(browser, parent):
@@ -96,21 +91,24 @@ def createItemsFun(browser, parent):
     dirProxy = parent._proxy
     
     # Get meta information from browser
-    nameFilter = browser.nameFilter()
     searchFilter = browser.searchFilter()
     searchFilter = searchFilter if searchFilter['pattern'] else None
     expandedDirs = browser.expandedDirs
     starredDirs = browser.starredDirs
     
+    # Prepare name filter info
+    nameFilters = browser.nameFilter().replace(',', ' ').split()
+    hideHidden = '!hidden' in nameFilters
+    nameFilters = [f for f in nameFilters if f not in ('', '!hiddden', 'hidden')]
     
     # Filter the contents of this folder
     try:
         dirs = []
         for entry in dirProxy.dirs():
             entry = cleanpath(entry)
-            if op.basename(entry).startswith('.'):
+            if hideHidden and op.basename(entry).startswith('.'):
                 continue # Skip hidden files
-            if hasHiddenAttribute(entry):
+            if hideHidden and hasHiddenAttribute(entry):
                 continue # Skip hidden files on Windows
             if op.basename(entry) == '__pycache__':
                 continue
@@ -119,30 +117,27 @@ def createItemsFun(browser, parent):
         files = []
         for entry in dirProxy.files():
             entry = cleanpath(entry)
-            if op.basename(entry).startswith('.'):
+            if hideHidden and op.basename(entry).startswith('.'):
                 continue # Skip hidden files
-            if hasHiddenAttribute(entry):
+            if hideHidden and hasHiddenAttribute(entry):
                 continue # Skip hidden files on Windows
-            if not _filterFileByName(op.basename(entry), nameFilter):
+            if not _filterFileByName(op.basename(entry), nameFilters):
                 continue
             files.append(entry)
     
     except (OSError, IOError) as err:
         ErrorItem(parent, str(err))
-        return 
+        return
     
     # Sort dirs (case insensitive)
-    dirs.sort(key=lambda x: x.lower())
+    dirs.sort(key=filename2sortkey)
     
-    # Sort files 
-    # (first by name, then by type, so finally they are by type, then name)
-    files.sort(key=lambda x: x.lower())
-    files.sort(key=lambda x: ext(x).lower())
-        
+    # Sort files (first by type, then by name, logically)
+    files.sort(key=filename2sortkey)
     
     if not searchFilter:
         
-        # Create dirs 
+        # Create dirs
         for path in dirs:
             starred = op.normcase(path) in starredDirs
             item = DirItem(parent, fsProxy.dir(path), starred)
@@ -153,7 +148,7 @@ def createItemsFun(browser, parent):
                 item.setExpanded(True)
             item.setHidden(False)
         
-        # Create files        
+        # Create files
         for path in files:
             item = FileItem(parent, fsProxy.file(path))
     
@@ -185,6 +180,28 @@ def createItemsFun(browser, parent):
     return len(dirs) + len(files)
 
 
+def filename2sortkey(name):
+    """ Convert a file or dir name to a tuple that can be used to
+    logically sort them. Sorting first by extension.
+    """
+    # Normalize name
+    name = os.path.basename(name).lower()
+    name, e = os.path.splitext(name)
+    # Split the name in logical parts
+    try:
+        numbers = '0123456789'
+        name1 = name.lstrip(numbers)
+        name2 = name1.rstrip(numbers)
+        n_pre = len(name) - len(name1)
+        n_post = len(name1) - len(name2)
+        pre = int(name[:n_pre]) if n_pre else 999999999
+        post = int(name[-n_post:]) if n_post else -1
+        return e, pre, name2, post
+    except Exception as err:
+        # I cannot see how this could fail, but lets be safe, as it would break so badly
+        print('Warning: could not filename2sortkey(%r), please report:\n%s' % (name, str(err)))
+        return (e, 999999999, name, -1)
+
 
 class BrowserItem(QtWidgets.QTreeWidgetItem):
     """ Abstract item in the tree widget.
@@ -291,7 +308,7 @@ class DirItem(BrowserItem):
         expandedDirs = self.treeWidget().parent().expandedDirs
         p = op.normcase(self.path())  # Normalize case!
         if p not in expandedDirs:
-            expandedDirs.append(p) 
+            expandedDirs.append(p)
         # Keep track of changes in our contents
         self._proxy.track()
         self._proxy.push()
@@ -348,7 +365,7 @@ class FileItem(BrowserItem):
                                     not QtCore.__file__.startswith('/usr/'):
             icon = iconprovider.icon(iconprovider.File)
         else:
-            icon = iconprovider.icon(QtCore.QFileInfo(dummy_filename))        
+            icon = iconprovider.icon(QtCore.QFileInfo(dummy_filename))
         icon = addIconOverlays(icon)
         self.setIcon(0, icon)
     
@@ -361,9 +378,8 @@ class FileItem(BrowserItem):
         # so that we can open files on any file system
         path = self.path()
         if ext(path) not in ['.pyc','.pyo','.png','.jpg','.ico']:
-            # Load and get editor
-            fileItem = pyzo.editors.loadFile(path)
-            editor = fileItem._editor
+            # Load file
+            pyzo.editors.loadFile(path)
             # Give focus
             pyzo.editors.getCurrentEditor().setFocus()
     
@@ -522,7 +538,7 @@ class TemporaryDirItem:
     def __init__(self, tree, pathProxy):
         self._tree = tree
         self._proxy = pathProxy
-        self._proxy.changed.connect(self.onChanged)        
+        self._proxy.changed.connect(self.onChanged)
         # Process asap, but do not track
         self._proxy.push()
         # Store ourself
@@ -549,7 +565,7 @@ class TemporaryFileItem:
     
     def __init__(self, tree, pathProxy):
         self._tree = tree
-        self._proxy = pathProxy   
+        self._proxy = pathProxy
         self._proxy.taskFinished.connect(self.onSearchResult)
         # Store ourself
         tree._temporaryItems.add(self)
@@ -609,7 +625,7 @@ class Tree(QtWidgets.QTreeWidget):
         
         # Define context menu
         self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
-        self.customContextMenuRequested.connect(self.contextMenuTriggered)  
+        self.customContextMenuRequested.connect(self.contextMenuTriggered)
         
         # Initialize proxy (this is where the path is stored)
         self._proxy = None
@@ -624,9 +640,9 @@ class Tree(QtWidgets.QTreeWidget):
     def setPath(self, path):
         """ Set the current path shown by the treeview.
         """
-        # Close old proxy        
+        # Close old proxy
         if self._proxy is not None:
-            self._proxy.cancel()        
+            self._proxy.cancel()
             self._proxy.changed.disconnect(self.onChanged)
             self._proxy.deleted.disconnect(self.onDeleted)
             self._proxy.errored.disconnect(self.onErrored)
@@ -647,7 +663,7 @@ class Tree(QtWidgets.QTreeWidget):
             self._proxy.push()
         # Store dir in config
         self.parent().config.path = path
-        # Signal that the dir has changed 
+        # Signal that the dir has changed
         # Note that our contents may not be visible yet.
         self.dirChanged.emit(self.path())
     
@@ -749,10 +765,10 @@ class Tree(QtWidgets.QTreeWidget):
     
     
     def _restoreSelectionState(self):
-        # First select the first item 
+        # First select the first item
         # (otherwise the scrolling wont work for some reason)
         if self.topLevelItemCount():
-            self.setCurrentItem(self.topLevelItem(0))       
+            self.setCurrentItem(self.topLevelItem(0))
         # Restore selection
         if self._selectedPath:
             items = self.findItems(op.basename(self._selectedPath), QtCore.Qt.MatchExactly, 0)
@@ -799,10 +815,10 @@ class PopupMenu(pyzo.core.menu.Menu):
         if isinstance(self._item, FileItem):
             self.addItem(translate("filebrowser", "Open"), None, self._item.onActivated)
             if self._item.path().endswith('.py'):
-                self.addItem(translate("filebrowser", "Run as script"), 
+                self.addItem(translate("filebrowser", "Run as script"),
                     None, self._runAsScript)
             elif self._item.path().endswith('.ipynb'):
-                self.addItem(translate("filebrowser", "Run Jupyter notebook"), 
+                self.addItem(translate("filebrowser", "Run Jupyter notebook"),
                     None, self._runNotebook)
             else:
                 self.addItem(translate("filebrowser", "Import data..."),
@@ -812,13 +828,13 @@ class PopupMenu(pyzo.core.menu.Menu):
         # Create items for open and copy path
         if isinstance(self._item, (FileItem, DirItem)):
             if isplat('win') or isplat('darwin') or isplat('linux'):
-                self.addItem(translate("filebrowser", "Open outside Pyzo"), 
+                self.addItem(translate("filebrowser", "Open outside Pyzo"),
                     None, self._openOutsidePyzo)
-            if isplat('darwin'):            
-                self.addItem(translate("filebrowser", "Reveal in Finder"), 
+            if isplat('darwin'):
+                self.addItem(translate("filebrowser", "Reveal in Finder"),
                     None, self._showInFinder)
             if True:
-                self.addItem(translate("filebrowser", "Copy path"), 
+                self.addItem(translate("filebrowser", "Copy path"),
                     None, self._copyPath)
             self.addSeparator()
         
@@ -969,12 +985,12 @@ class PopupMenu(pyzo.core.menu.Menu):
     
     def onDelete(self):
         # Ask for new filename
-        b = QtWidgets.QMessageBox.question(self.parent(), 
-                    translate("filebrowser", "Delete"), 
-                    translate("filebrowser", "Are you sure that you want to delete") + 
+        b = QtWidgets.QMessageBox.question(self.parent(),
+                    translate("filebrowser", "Delete"),
+                    translate("filebrowser", "Are you sure that you want to delete") +
                     ':\n%s' % self._item.path(),
                     QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.Cancel,
-                )       
+                )
         # Push delete task
-        if b is QtWidgets.QMessageBox.Yes:            
+        if b is QtWidgets.QMessageBox.Yes:
             self._item._proxy.pushTask(tasks.RemoveTask())
