@@ -4,9 +4,6 @@
 # Pyzo is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
 
-
-import time
-
 import pyzo
 from pyzo.util.qt import QtCore, QtGui, QtWidgets
 from pyzo import translate
@@ -15,6 +12,12 @@ tool_name = "Source structure"
 tool_summary = "Shows the structure of your source code."
 
 
+class Navigation:
+    def __init__(self):
+        self.back = []
+        self.forward = []
+
+
 class PyzoSourceStructure(QtWidgets.QWidget):
     def __init__(self, parent):
         QtWidgets.QWidget.__init__(self, parent)
@@ -22,31 +25,47 @@ class PyzoSourceStructure(QtWidgets.QWidget):
         # Make sure there is a configuration entry for this tool
         # The pyzo tool manager makes sure that there is an entry in
         # config.tools before the tool is instantiated.
-        toolId = self.__class__.__name__.lower()        
+        toolId = self.__class__.__name__.lower()
         self._config = pyzo.config.tools[toolId]
         if not hasattr(self._config, 'showTypes'):
             self._config.showTypes = ['class', 'def', 'cell', 'todo']
         if not hasattr(self._config, 'level'):
             self._config.level = 2
         
-        # Create icon for slider
-        self._sliderIcon = QtWidgets.QToolButton(self)
-        self._sliderIcon.setIcon(pyzo.icons.text_align_right)
-        self._sliderIcon.setIconSize(QtCore.QSize(16,16))
-        self._sliderIcon.setStyleSheet("QToolButton { border: none; padding: 0px; }")   
+        # Keep track of clicks so we can "go back"
+        self._nav = {}  # editor-id -> Navigation object
+        
+        # Create buttons for navigation
+        self._navbut_back = QtWidgets.QToolButton(self)
+        self._navbut_back.setIcon(pyzo.icons.arrow_left)
+        self._navbut_back.setIconSize(QtCore.QSize(16,16))
+        self._navbut_back.setStyleSheet("QToolButton { border: none; padding: 0px; }")
+        self._navbut_back.clicked.connect(self.onNavBack)
+        #
+        self._navbut_forward = QtWidgets.QToolButton(self)
+        self._navbut_forward.setIcon(pyzo.icons.arrow_right)
+        self._navbut_forward.setIconSize(QtCore.QSize(16,16))
+        self._navbut_forward.setStyleSheet("QToolButton { border: none; padding: 0px; }")
+        self._navbut_forward.clicked.connect(self.onNavForward)
+        
+        # # Create icon for slider
+        # self._sliderIcon = QtWidgets.QToolButton(self)
+        # self._sliderIcon.setIcon(pyzo.icons.text_align_right)
+        # self._sliderIcon.setIconSize(QtCore.QSize(16,16))
+        # self._sliderIcon.setStyleSheet("QToolButton { border: none; padding: 0px; }")
         
         # Create slider
         self._slider = QtWidgets.QSlider(QtCore.Qt.Horizontal, self)
         self._slider.setTickPosition(QtWidgets.QSlider.TicksBelow)
         self._slider.setSingleStep(1)
         self._slider.setPageStep(1)
-        self._slider.setRange(1,9)
+        self._slider.setRange(1,5)
         self._slider.setValue(self._config.level)
         self._slider.valueChanged.connect(self.updateStructure)
         
         # Create options button
         #self._options = QtWidgets.QPushButton(self)
-        #self._options.setText('Options'))        
+        #self._options.setText('Options'))
         #self._options.setToolTip("What elements to show.")
         self._options = QtWidgets.QToolButton(self)
         self._options.setIcon(pyzo.icons.filter)
@@ -58,7 +77,7 @@ class PyzoSourceStructure(QtWidgets.QWidget):
         self._options._menu = QtWidgets.QMenu()
         self._options.setMenu(self._options._menu)
         
-        # Create tree widget        
+        # Create tree widget
         self._tree = QtWidgets.QTreeWidget(self)
         self._tree.setHeaderHidden(True)
         self._tree.itemCollapsed.connect(self.updateStructure) # keep expanded
@@ -73,10 +92,13 @@ class PyzoSourceStructure(QtWidgets.QWidget):
         # Set layout
         self._sizer1.addLayout(self._sizer2, 0)
         self._sizer1.addWidget(self._tree, 1)
-        self._sizer2.addWidget(self._sliderIcon, 0)
-        self._sizer2.addWidget(self._slider, 4)
+        # self._sizer2.addWidget(self._sliderIcon, 0)
+        self._sizer2.addWidget(self._navbut_back, 0)
+        self._sizer2.addWidget(self._navbut_forward, 0)
         self._sizer2.addStretch(1)
-        self._sizer2.addWidget(self._options, 2)
+        self._sizer2.addWidget(self._slider, 6)
+        self._sizer2.addStretch(1)
+        self._sizer2.addWidget(self._options, 0)
         #
         self.setLayout(self._sizer1)
         
@@ -135,7 +157,7 @@ class PyzoSourceStructure(QtWidgets.QWidget):
         file is shown. """
         
         # Get editor and clear list
-        editor = pyzo.editors.getCurrentEditor()        
+        editor = pyzo.editors.getCurrentEditor()
         self._tree.clear()
         
         if editor is None:
@@ -148,33 +170,68 @@ class PyzoSourceStructure(QtWidgets.QWidget):
             
             # Notify
             text = translate('pyzoSourceStructure', 'Parsing ' + editor._name + ' ...')
-            thisItem = QtWidgets.QTreeWidgetItem(self._tree, [text])
+            QtWidgets.QTreeWidgetItem(self._tree, [text])
             
             # Try getting the  structure right now
             self.updateStructure()
     
     
+    def _getCurrentNav(self):
+        if not self._currentEditorId:
+            return None
+        if self._currentEditorId not in self._nav:
+            self._nav[self._currentEditorId] = Navigation()
+        return self._nav[self._currentEditorId]
+    
+    def onNavBack(self):
+        nav = self._getCurrentNav()
+        if not nav or not nav.back:
+            return
+        linenr = nav.back.pop(-1)
+        old_linenr = self._navigate_to_line(linenr)
+        if old_linenr is not None:
+            nav.forward.append(old_linenr)
+    
+    def onNavForward(self):
+        nav = self._getCurrentNav()
+        if not nav or not nav.forward:
+            return
+        linenr = nav.forward.pop(-1)
+        old_linenr = self._navigate_to_line(linenr)
+        if old_linenr is not None:
+            nav.back.append(old_linenr)
+
     def onItemClick(self, item):
         """ Go to the right line in the editor and give focus. """
         
-        # Get editor
-        editor = pyzo.editors.getCurrentEditor()
-        if not editor:
-            return
-        
         # If item is attribute, get parent
         if not item.linenr:
             item = item.parent()
         
-        # Move to line
-        editor.gotoLine(item.linenr)
+        old_linenr = self._navigate_to_line(item.linenr)
         
+        if old_linenr is not None:
+            nav = self._getCurrentNav()
+            if nav and (not nav.back or nav.back[-1] != old_linenr):
+                nav.back.append(old_linenr)
+                nav.forward = []
+    
+    def _navigate_to_line(self, linenr):
+        
+        # Get editor
+        editor = pyzo.editors.getCurrentEditor()
+        if not editor:
+            return None
+        # Keep current line nr
+        old_linenr = editor.textCursor().blockNumber() + 1
+        # Move to line
+        editor.gotoLine(linenr)
         # Give focus
         pyzo.callLater(editor.setFocus)
+        return old_linenr
 
-    
     def updateStructure(self):
-        """ Updates the tree. 
+        """ Updates the tree.
         """
         
         # Get editor
@@ -188,7 +245,7 @@ class PyzoSourceStructure(QtWidgets.QWidget):
             return
         
         # Do the ids match?
-        id0, id1, id2 = self._currentEditorId, id(editor), result.editorId 
+        id0, id1, id2 = self._currentEditorId, id(editor), result.editorId
         if id0 != id1 or id0 != id2:
             return
         
@@ -197,8 +254,9 @@ class PyzoSourceStructure(QtWidgets.QWidget):
         ln += 1  # is ln as in line number area
         
         # Define colours
-        colours = {'cell':'#007F00', 'class':'#0000FF', 'def':'#007F7F', 
-                    'attribute':'#444444', 'import':'#8800BB', 'todo':'#FF3333'}
+        colours = {'cell':'#007F00', 'class':'#0000FF', 'def':'#007F7F',
+                    'attribute':'#444444', 'import':'#8800BB', 'todo':'#FF3333',
+                    'nameismain':'#007F00'}
         
         # Define what to show
         showTypes = self._config.showTypes
@@ -206,6 +264,7 @@ class PyzoSourceStructure(QtWidgets.QWidget):
         # Define to what level to show (now is also a good time to save)
         showLevel = int( self._slider.value() )
         self._config.level = showLevel
+        showLevel = showLevel if showLevel < 5 else 99
         
         # Define function to set items
         selectedItem = [None]
@@ -213,7 +272,7 @@ class PyzoSourceStructure(QtWidgets.QWidget):
             level += 1
             for object in fictiveObjects:
                 type = object.type
-                if not type in showTypes:
+                if type not in showTypes and type != 'nameismain':
                     continue
                 # Construct text
                 if type in ('cell', '##', '#%%', '# %%'):
@@ -221,10 +280,12 @@ class PyzoSourceStructure(QtWidgets.QWidget):
                 elif type=='attribute':
                     type = 'attr'
                 #
-                if type == 'import':                   
+                if type == 'import':
                     text = "%s (%s)" % (object.name, object.text)
                 elif type=='todo':
                     text = object.name
+                elif type=='nameismain':
+                    text = object.text
                 else:
                     text = "%s %s" % (type, object.name)
                 # Create item
@@ -237,11 +298,11 @@ class PyzoSourceStructure(QtWidgets.QWidget):
                 thisItem.linenr = object.linenr
                 # Is this the current item?
                 if ln and object.linenr <= ln and object.linenr2 > ln:
-                    selectedItem[0] = thisItem 
+                    selectedItem[0] = thisItem
                 # Any children that we should display?
                 if object.children:
                     SetItems(thisItem, object.children, level)
-                # Set visibility 
+                # Set visibility
                 thisItem.setExpanded( bool(level < showLevel) )
         
         # Go
