@@ -5,9 +5,7 @@
 # The full license can be found in 'license.txt'.
 
 
-import sys, os, time
-
-import pyzo 
+import pyzo
 from pyzo.util.qt import QtCore, QtGui, QtWidgets
 
 tool_name = "Workspace"
@@ -16,18 +14,18 @@ tool_summary = "Lists the variables in the current shell's namespace."
 
 
 def splitName(name):
-    """ splitName(name)    
+    """ splitName(name)
     Split an object name in parts, taking dots and indexing into account.
-    """    
+    """
     name = name.replace('[', '.[')
     parts = name.split('.')
     return [p for p in parts if p]
 
 
 def joinName(parts):
-    """ joinName(parts)    
+    """ joinName(parts)
     Join the parts of an object name, taking dots and indexing into account.
-    """    
+    """
     name = '.'.join(parts)
     return name.replace('.[', '[')
 
@@ -71,8 +69,8 @@ class WorkspaceProxy(QtCore.QObject):
     
     
     def setName(self, name):
-        """ setName(name)        
-        Set the name that we want to know more of. 
+        """ setName(name)
+        Set the name that we want to know more of.
         """
         self._name = name
         
@@ -84,7 +82,7 @@ class WorkspaceProxy(QtCore.QObject):
     
     def goUp(self):
         """ goUp()
-        Cut the last part off the name. 
+        Cut the last part off the name.
         """
         parts = splitName(self._name)
         if parts:
@@ -95,7 +93,7 @@ class WorkspaceProxy(QtCore.QObject):
     def onCurrentShellChanged(self):
         """ onCurrentShellChanged()
         When no shell is selected now, update this. In all other cases,
-        the onCurrentShellStateChange will be fired too. 
+        the onCurrentShellStateChange will be fired too.
         """
         shell = pyzo.shells.getCurrentShell()
         if not shell:
@@ -105,8 +103,8 @@ class WorkspaceProxy(QtCore.QObject):
     
     def onCurrentShellStateChanged(self):
         """ onCurrentShellStateChanged()
-        Do a request for information! 
-        """ 
+        Do a request for information!
+        """
         shell = pyzo.shells.getCurrentShell()
         if not shell:
             # Should never happen I think, but just to be sure
@@ -149,11 +147,11 @@ class WorkspaceTree(QtWidgets.QTreeWidget):
     """ WorkspaceTree
     
     The tree that displays the items in the current namespace.
-    I first thought about implementing this using the mode/view 
-    framework, but it is so much work and I can't seem to fully 
+    I first thought about implementing this using the mode/view
+    framework, but it is so much work and I can't seem to fully
     understand how it works :(
     
-    The QTreeWidget is so very simple and enables sorting very 
+    The QTreeWidget is so very simple and enables sorting very
     easily, so I'll stick with that ...
     
     """
@@ -189,7 +187,7 @@ class WorkspaceTree(QtWidgets.QTreeWidget):
     
     def contextMenuEvent(self, event):
         """ contextMenuEvent(event)
-        Show the context menu. 
+        Show the context menu.
         """
         
         QtWidgets.QTreeView.contextMenuEvent(self, event)
@@ -261,7 +259,7 @@ class WorkspaceTree(QtWidgets.QTreeWidget):
         for des in self._proxy._variables:
             
             # Get parts
-            parts = des.split(',',4)
+            parts = des.split(',',3)
             if len(parts) < 4:
                 continue
             
@@ -270,6 +268,15 @@ class WorkspaceTree(QtWidgets.QTreeWidget):
             # Pop the 'kind' element
             kind = parts.pop(2)
             
+            # <kludge 2>
+            # the typeTranslation dictionary contains "synonyms" for types that will be hidden
+            # Currently only "method"->"function" is used
+            # the try:... is there to have a minimal translation dictionary.
+            try:
+                kind = self._config.typeTranslation[kind]
+            except KeyError:
+                pass
+            # </kludge 2>
             if kind in self._config.hideTypes:
                 continue
             if name.startswith('_') and 'private' in self._config.hideTypes:
@@ -299,10 +306,20 @@ class PyzoWorkspace(QtWidgets.QWidget):
         # Make sure there is a configuration entry for this tool
         # The pyzo tool manager makes sure that there is an entry in
         # config.tools before the tool is instantiated.
-        toolId = self.__class__.__name__.lower()        
+        toolId = self.__class__.__name__.lower()
         self._config = pyzo.config.tools[toolId]
         if not hasattr(self._config, 'hideTypes'):
             self._config.hideTypes = []
+        # <kludge 2>
+        # configuring the typeTranslation dictionary
+        if not hasattr(self._config, 'typeTranslation'):
+            # to prevent the exception to be raised, one could init to :
+            # {"method": "function", "function": "function", "type": "type", "private": "private", "module": "module"}
+            self._config.typeTranslation = {}
+        # Defaults
+        self._config.typeTranslation['method'] = 'function'
+        self._config.typeTranslation['builtin_function_or_method'] = 'function'
+        # <kludge 2>
         
         # Create tool button
         self._up = QtWidgets.QToolButton(self)
